package com.hzya.frame.grpU8.nxproof.pubkjqj.dao;

import com.hzya.frame.basedao.dao.IBaseDao;
import com.hzya.frame.grpU8.nxproof.pubkjqj.entity.SenderPubkjqjEntity;

import java.util.List;

/**
 * (pubkjqj: table)表数据库访问层
 *
 * @author makejava
 * @since 2024-06-20 09:49:34
 */
public interface ISenderPubkjqjDao extends IBaseDao<SenderPubkjqjEntity, String> {
    /**
     *
     * @content 查询会计期间  卫生院
     * @Param
     * @Return
     * @Author hecan
     * @Date 2024/6/20 10:11
     * **/
    List<SenderPubkjqjEntity> querySenderPubkjqjEntity(SenderPubkjqjEntity senderPubkjqjEntity);
    
    /**
     * 
     * @content 保存会计期间到会计期间日志表中 卫生院
     * @Param 
     * @Return 
     * @Author hecan 
     * @Date 2024/6/27 9:41
     * **/
    SenderPubkjqjEntity saveSenderPubkjqjEntity(SenderPubkjqjEntity senderPubkjqjEntity);
    
    /**
     * 
     * @content 更新会计期间到会计期间日志表中 卫生院
     * @Param 
     * @Return 
     * @Author hecan 
     * @Date 2024/6/27 9:42
     * **/
    SenderPubkjqjEntity updateSenderPubkjqjEntity(SenderPubkjqjEntity senderPubkjqjEntity);

    /**
     *
     * @content 查询会计期间  卫生局
     * @Param
     * @Return
     * @Author hecan
     * @Date 2024/6/20 10:11
     * **/
    List<SenderPubkjqjEntity> queryPubkjqjHealthBureau(SenderPubkjqjEntity senderPubkjqjEntity);

    /**
     *
     * @content 保存会计期间 卫生局
     * @Param
     * @Return
     * @Author hecan
     * @Date 2024/6/27 9:41
     * **/
    SenderPubkjqjEntity savePubkjqjHealthBureau(SenderPubkjqjEntity senderPubkjqjEntity);

    /**
     *
     * @content 更新会计期间 卫生局
     * @Param
     * @Return
     * @Author hecan
     * @Date 2024/6/27 9:42
     * **/
    SenderPubkjqjEntity updatePubkjqjHealthBureau(SenderPubkjqjEntity senderPubkjqjEntity);

    /**
     *
     * @content 删除会计期间 卫生局
     * @Param
     * @Return
     * @Author hecan
     * @Date 2024/8/9 17:34
     * **/
    Integer deletePubkjqjHealthBureau(SenderPubkjqjEntity senderPubkjqjEntity);



}

